@@ -67,6 +67,7 @@
 (menu-bind graphics-frame-unit-menu
   ("1 cm" (graphics-set-unit "1cm"))
   ("1 inch" (graphics-set-unit "1in"))
+  ("0.1 par" (graphics-set-unit "0.1par"))
   ;;("5 em" (graphics-set-unit "5em"))
   ---
   ("Other" (interactive graphics-set-unit)))
@@ -127,7 +128,8 @@
 
 (menu-bind graphics-visual-grid-menu
   (-> "Type"
-      ("No grid"     (graphics-set-visual-grid 'empty))
+      ;;("No grid"     (graphics-set-visual-grid 'empty))
+      ("No grid"     (graphics-reset-grids))
       ---
       ("Cartesian"   (graphics-set-visual-grid 'cartesian))
       ("Polar"       (graphics-set-visual-grid 'polar))
@@ -266,7 +268,8 @@
 	("Other" (graphics-interactive-set-grid-nsubds #f)))))
 
 (menu-bind graphics-grids-menu
-  ("Default" (graphics-reset-grids))
+  ("Show grid" (graphics-toggle-grid))
+  ;;("Default" (graphics-reset-grids))
   ---
   (link graphics-visual-grid-menu))
 
@@ -357,7 +360,7 @@
   (pick-color (graphics-set-grid-color 'units answer))
   ---
   ("Palette" (interactive-color
-              (lambda (c) (graphics-set-color 'units c)) '()))
+              (lambda (c) (graphics-set-grid-color 'units c)) '()))
   ("Other" (interactive
 	       (lambda (x) (graphics-set-grid-color 'units x)) "Color")))
 
@@ -559,7 +562,7 @@
   ---
   (if (!= (graphics-get-grid-type #t) 'empty)
       ("Grid points" (graphics-toggle-snap "grid point"))
-      ("Grid curves" (graphics-toggle-snap "grid curve point"))
+      ("Grid lines" (graphics-toggle-snap "grid curve point"))
       ("Grid-curve intersections"
        (graphics-toggle-snap "curve-grid intersection")))
   ("Curve points" (graphics-toggle-snap "curve point"))
